Module app

Module app 

Re-exports

pub use crate::core::SessionAppearanceConfig;
pub use crate::core_tui::app::types::*;

Modules

prelude
Commonly used VT Code TUI API items.

Structs

KeyboardProtocolSettings
Standalone keyboard protocol settings for terminal key event enhancements.
SessionOptions
Standalone session launch options for reusable integrations.

Enums

SessionSurface
Standalone surface preference for selecting inline vs alternate rendering.

Functions

spawn_session_with_host
Spawn a session using defaults from a host adapter.
spawn_session_with_options
Spawn a session using standalone options and local config types.