pub enum InlineListSelection {
Show 28 variants
Model(usize),
DynamicModel(usize),
CustomProvider(usize),
RefreshDynamicModels,
Reasoning(String),
DisableReasoning,
OpenAIServiceTier(OpenAIServiceTierChoice),
CustomModel,
Theme(String),
Session(String),
SessionForkMode {
session_id: String,
summarize: bool,
},
ConfigAction(String),
SlashCommand(String),
ToolApproval(bool),
ToolApprovalDenyOnce,
ToolApprovalSession,
ToolApprovalPermanent,
FileConflictReload,
FileConflictViewDiff,
FileConflictAbort,
SessionLimitIncrease(usize),
RewindCheckpoint(usize),
RewindAction(RewindAction),
AskUserChoice {
tab_id: String,
choice_id: String,
text: Option<String>,
},
RequestUserInputAnswer {
question_id: String,
selected: Vec<String>,
other: Option<String>,
},
PlanApprovalExecute,
PlanApprovalEditPlan,
PlanApprovalAutoAccept,
}Expand description
Selection value returned from a list or wizard overlay.
The Reasoning variant carries a String reasoning-effort level rather
than a typed enum so that this type stays free of config-crate dependencies.
Callers convert to/from their local ReasoningEffortLevel as needed.
Variants
Model(usize)
DynamicModel(usize)
CustomProvider(usize)
RefreshDynamicModels
Reasoning(String)
DisableReasoning
OpenAIServiceTier(OpenAIServiceTierChoice)
CustomModel
Theme(String)
Session(String)
SessionForkMode
ConfigAction(String)
SlashCommand(String)
ToolApproval(bool)
ToolApprovalDenyOnce
ToolApprovalSession
ToolApprovalPermanent
FileConflictReload
FileConflictViewDiff
FileConflictAbort
SessionLimitIncrease(usize)
RewindCheckpoint(usize)
RewindAction(RewindAction)
AskUserChoice
Selection shape used by legacy tabbed HITL flows.
RequestUserInputAnswer
Selection returned from the request_user_input HITL tool.
PlanApprovalExecute
Plan confirmation dialog result (human-in-the-loop flow).
PlanApprovalEditPlan
Return to planning to edit the plan.
PlanApprovalAutoAccept
Auto-accept all future plans in this session.