Module modal

Module modal 

Structs

ModalBodyContext
ModalKeyModifiers
ModalListItem
ModalListState
ModalRenderStyles
ModalSearchState
ModalState
WizardModalState
State for a multi-step wizard modal with tabs for navigation
WizardStepState
State for a single wizard step

Enums

ModalListKeyResult
ModalSection

Functions

is_divider_title
modal_list_item_lines
render_modal_body
render_modal_list
render_wizard_modal_body
Render wizard modal body including tabs, question, and list
render_wizard_tabs
Render wizard tabs header showing steps with completion status