pub fn spawn_session_with_host(
theme: InlineTheme,
host: &impl HostAdapter,
) -> Result<InlineSession>Expand description
Spawn a session using defaults from a host adapter.
pub fn spawn_session_with_host(
theme: InlineTheme,
host: &impl HostAdapter,
) -> Result<InlineSession>Spawn a session using defaults from a host adapter.