Module markdown

Module markdown 

Markdown rendering utilities for terminal output with syntax highlighting support.

Structs

HighlightedSegment
MarkdownLine
A rendered line composed of styled segments.
MarkdownSegment
A styled text segment.
RenderMarkdownOptions

Functions

highlight_code_to_ansi
highlight_code_to_segments
highlight_line_for_diff
render_markdown
Convenience helper that renders markdown using the active theme without emitting output.
render_markdown_to_lines
Render markdown text to styled lines that can be written to the terminal renderer.
render_markdown_to_lines_with_options