pub fn render_markdown(source: &str) -> Vec<MarkdownLine>Expand description
Convenience helper that renders markdown using the active theme without emitting output.
pub fn render_markdown(source: &str) -> Vec<MarkdownLine>Convenience helper that renders markdown using the active theme without emitting output.