fuzzy_match

Function fuzzy_match 

pub fn fuzzy_match(query: &str, candidate: &str) -> bool
Returns true when every term in the query appears as a fuzzy match within the candidate text using nucleo-matcher.