pub fn diff_scope_background_rgbs() -> DiffScopeBackgroundRgbsExpand description
Resolve diff-scope background colors from the currently active syntax theme.
pub fn diff_scope_background_rgbs() -> DiffScopeBackgroundRgbsResolve diff-scope background colors from the currently active syntax theme.