suggest_theme_for_terminal

Function suggest_theme_for_terminal 

pub fn suggest_theme_for_terminal() -> &'static str
Get a suggested theme based on terminal color scheme detection. Returns a light or dark theme depending on detected terminal background.