pub fn compute_diff_with_theme(
old: &str,
new: &str,
options: DiffOptions<'_>,
) -> DiffBundleExpand description
Compute a structured diff bundle using the default theme-aware formatter.
pub fn compute_diff_with_theme(
old: &str,
new: &str,
options: DiffOptions<'_>,
) -> DiffBundleCompute a structured diff bundle using the default theme-aware formatter.