Commonly used VT Code TUI API items.
Re-exports
pub use super::FullscreenInteractionSettings;pub use super::InlineCommand;pub use super::InlineEvent;pub use super::InlineHandle;pub use super::InlineSession;pub use super::SessionAppearanceConfig;pub use super::SessionOptions;pub use super::TrustMode;pub use super::spawn_session_with_host;pub use super::spawn_session_with_options;
Structs
- Inline
Segment - A styled text segment with shared style.
- Inline
Text Style - Inline text styling with foreground/background color and text effects.
- Inline
Theme - Resolved theme colors for inline rendering.
- Keyboard
Protocol Settings - Standalone keyboard protocol settings for terminal key event enhancements.
- Plan
Content - Structured plan content for display in the Implementation Blueprint panel.
- Plan
Phase - A phase in an implementation plan (groups related steps).
- Plan
Step - A step in an implementation plan.
- Slash
Command Item - A single slash-command entry for the suggestion palette.
- Wizard
Step - A single step in a wizard modal flow.
Enums
- Inline
Message Kind - Message kind tag for inline transcript lines.
- Session
Surface - Standalone surface preference for selecting inline vs alternate rendering.
- Wizard
Modal Mode - Wizard modal behavior variant.