Re-exports
pub use style::theme_from_styles;pub use theme_parser::ThemeConfigParser;pub use types::ContentPart;pub use types::FocusChangeCallback;pub use types::InlineCommand;pub use types::InlineEvent;pub use types::InlineEventCallback;pub use types::InlineHandle;pub use types::InlineSession;pub use types::ListOverlayRequest;pub use types::ModalOverlayRequest;pub use types::OverlayEvent;pub use types::OverlayHotkey;pub use types::OverlayHotkeyAction;pub use types::OverlayHotkeyKey;pub use types::OverlayRequest;pub use types::OverlaySelectionChange;pub use types::OverlaySubmission;pub use types::WizardOverlayRequest;
Modules
- alternate_
screen - app
- log
- panic_
hook - Panic hook implementation for terminal UI applications This module provides a panic hook that restores terminal state when a panic occurs, preventing terminal corruption, and provides enhanced panic formatting for different build types.
- runner
- session
- style
- theme_
parser - Parse theme configuration from multiple syntaxes (Git, LS_COLORS, custom).
- types
- widgets
Structs
- Inline
Header Badge - A compact pill badge rendered in the header.
- Inline
Header Context - Session metadata displayed in the inline header.
- Inline
Header Highlight - A title + content highlight block in the header.
- Inline
Header Status Badge - A labelled status badge for the header bar.
- Inline
Link Range - Byte-range inside a line that is a clickable link.
- Inline
List Item - A selectable item inside a list overlay.
- Inline
List Search Config - Search configuration for a list overlay.
- Inline
Segment - A styled text segment with shared style.
- Inline
Text Style - Inline text styling with foreground/background color and text effects.
- Inline
Theme - Resolved theme colors for inline rendering.
- Secure
Prompt Config - Configuration for a secure (masked) prompt input.
- Wizard
Step - A single step in a wizard modal flow.
Enums
- Editing
Mode - Editing mode for the agent session.
- Inline
Header Status Tone - Status-badge tone used in header status indicators.
- Inline
Link Target - A clickable link target inside a transcript line.
- Inline
List Selection - Selection value returned from a list or wizard overlay.
- Inline
Message Kind - Message kind tag for inline transcript lines.
- Rewind
Action - Rewind action choices for the rewind overlay.
- Wizard
Modal Mode - Wizard modal behavior variant.
Functions
- convert_
style - Convert an
anstyle::Styleto anInlineTextStyle. - spawn_
session - spawn_
session_ with_ prompts - Spawn session with optional custom prompts pre-loaded
- spawn_
session_ with_ prompts_ and_ options - Spawn session with host-injected UI options.