Re-exports
pub use style::convert_style;pub use style::theme_from_styles;pub use theme_parser::ThemeConfigParser;pub use types::ContentPart;pub use types::DiffHunk;pub use types::DiffPreviewState;pub use types::EditingMode;pub use types::FocusChangeCallback;pub use types::InlineCommand;pub use types::InlineEvent;pub use types::InlineEventCallback;pub use types::InlineHandle;pub use types::InlineHeaderContext;pub use types::InlineHeaderHighlight;pub use types::InlineListItem;pub use types::InlineListSearchConfig;pub use types::InlineListSelection;pub use types::InlineMessageKind;pub use types::InlineSegment;pub use types::InlineSession;pub use types::InlineTextStyle;pub use types::InlineTheme;pub use types::PlanConfirmationResult;pub use types::PlanContent;pub use types::PlanPhase;pub use types::PlanStep;pub use types::SecurePromptConfig;pub use types::SlashCommandItem;pub use types::TrustMode;pub use types::WizardModalMode;pub use types::WizardStep;
Modules
- alternate_
screen - log
- panic_
hook - Panic hook implementation for terminal UI applications This module provides a panic hook that restores terminal state when a panic occurs, preventing terminal corruption, and provides enhanced panic formatting for different build types.
- runner
- session
- style
- theme_
parser - Parse theme configuration from multiple syntaxes (Git, LS_COLORS, custom).
- types
- widgets
Functions
- spawn_
session - spawn_
session_ with_ prompts - Spawn session with optional custom prompts pre-loaded
- spawn_
session_ with_ prompts_ and_ options - Spawn session with host-injected UI options.