pub struct FilePalette { /* private fields */ }Implementations
Sourceimpl FilePalette
impl FilePalette
pub fn load_files(&mut self, files: Vec<String>)
pub fn set_filter(&mut self, query: String)
Sourcepub fn style_for_entry(&self, entry: &FileEntry) -> Option<Style>
pub fn style_for_entry(&self, entry: &FileEntry) -> Option<Style>
Get the appropriate style for a file entry based on its path and type
Sourceimpl FilePalette
impl FilePalette
pub fn move_selection_up(&mut self)
pub fn move_selection_down(&mut self)
pub fn move_to_first(&mut self)
pub fn move_to_last(&mut self)
pub fn page_up(&mut self)
pub fn page_down(&mut self)
pub fn get_selected(&self) -> Option<&FileEntry>
Sourcepub fn get_best_match(&self) -> Option<&FileEntry>
pub fn get_best_match(&self) -> Option<&FileEntry>
Get the best matching file entry based on current filter query Used for Tab autocomplete - returns the first filtered file if any exist
Sourcepub fn select_best_match(&mut self)
pub fn select_best_match(&mut self)
Set selection to the best match
pub fn current_page_items(&self) -> Vec<(usize, &FileEntry, bool)>
pub fn total_pages(&self) -> usize
pub fn current_page_number(&self) -> usize
pub fn total_items(&self) -> usize
pub fn is_empty(&self) -> bool
pub fn filter_query(&self) -> &str
pub fn has_files(&self) -> bool
pub fn has_more_items(&self) -> bool