pub struct SessionStyles { /* private fields */ }Expand description
Styling utilities for the Session UI
Implementations
Sourceimpl SessionStyles
impl SessionStyles
pub fn new(theme: InlineTheme) -> Self
pub fn theme(&self) -> &InlineTheme
pub fn set_theme(&mut self, theme: InlineTheme)
Sourcepub fn modal_list_highlight_style(&self) -> Style
pub fn modal_list_highlight_style(&self) -> Style
Get the modal list highlight style
Sourcepub fn tool_inline_style(&self, tool_name: &str) -> InlineTextStyle
pub fn tool_inline_style(&self, tool_name: &str) -> InlineTextStyle
Get the inline style for a tool based on its name
Sourcepub fn tool_border_style(&self) -> InlineTextStyle
pub fn tool_border_style(&self) -> InlineTextStyle
Get the tool border style
Sourcepub fn default_style(&self) -> Style
pub fn default_style(&self) -> Style
Get the default style
Sourcepub fn default_inline_style(&self) -> InlineTextStyle
pub fn default_inline_style(&self) -> InlineTextStyle
Get the default inline style (for tests and inline conversions)
Sourcepub fn accent_inline_style(&self) -> InlineTextStyle
pub fn accent_inline_style(&self) -> InlineTextStyle
Get the accent inline style
Sourcepub fn accent_style(&self) -> Style
pub fn accent_style(&self) -> Style
Get the accent style
Sourcepub fn border_inline_style(&self) -> InlineTextStyle
pub fn border_inline_style(&self) -> InlineTextStyle
Get the border inline style
Sourcepub fn border_style(&self) -> Style
pub fn border_style(&self) -> Style
Get the border style (dimmed)
Sourcepub fn dimmed_border_style(&self, suppress_bold: bool) -> Style
pub fn dimmed_border_style(&self, suppress_bold: bool) -> Style
Get a border style with configurable boldness.
When suppress_bold is true, the BOLD modifier is removed — useful for
info/error/warning block borders that should appear subtle.
pub fn input_background_style(&self) -> Style
Sourcepub fn prefix_style(&self, line: &MessageLine) -> InlineTextStyle
pub fn prefix_style(&self, line: &MessageLine) -> InlineTextStyle
Get the prefix style for a message line
Sourcepub fn text_fallback(&self, kind: InlineMessageKind) -> Option<AnsiColorEnum>
pub fn text_fallback(&self, kind: InlineMessageKind) -> Option<AnsiColorEnum>
Get the fallback text color for a message kind
Sourcepub fn message_divider_style(&self, kind: InlineMessageKind) -> Style
pub fn message_divider_style(&self, kind: InlineMessageKind) -> Style
Get the message divider style