Markdown rendering utilities for terminal output with syntax highlighting support.
Structs
- Highlighted
Segment - Markdown
Line - A rendered line composed of styled segments.
- Markdown
Segment - A styled text segment.
- Render
Markdown Options
Functions
- highlight_
code_ to_ ansi - highlight_
code_ to_ segments - highlight_
line_ for_ diff - render_
markdown - Convenience helper that renders markdown using the active theme without emitting output.
- render_
markdown_ to_ lines - Render markdown text to styled lines that can be written to the terminal renderer.
- render_
markdown_ to_ lines_ with_ options